@@ -1,4 +1,4 @@
-class AddAutocryptHeaderToList < ActiveRecord::Migration
+class AddAutocryptHeaderToList < ActiveRecord::Migration[4.2]
   def up
     if ! column_exists?(:lists, :include_autocrypt_header)
       add_column :lists, :include_autocrypt_header, :boolean, default: true
