@@ -6,6 +6,7 @@
 Encoding.default_external = Encoding::UTF_8
 
 # Stdlib
+require 'etc'
 require 'fileutils'
 require 'singleton'
 require 'yaml'
@@ -13,10 +14,13 @@ require 'pathname'
 require 'syslog/logger'
 require 'logger'
 require 'open3'
+require 'socket'
 
 # Require mandatory libs. The database-layer-lib is required below.
 require 'mail-gpg'
 require 'active_record'
+require 'active_support'
+require 'active_support/core_ext/string'
 
 # An extra from mail-gpg
 require 'hkp'
@@ -30,7 +34,8 @@ $:.unshift libdir
 require 'schleuder/mail/parts_list.rb'
 require 'schleuder/mail/message.rb'
 require 'schleuder/mail/gpg.rb'
-require 'schleuder/mail/encrypted_part.rb'
+require 'schleuder/mail/gpg/encrypted_part.rb'
+require 'schleuder/mail/gpg/sign_part.rb'
 require 'schleuder/gpgme/import_status.rb'
 require 'schleuder/gpgme/key.rb'
 require 'schleuder/gpgme/sub_key.rb'
@@ -48,10 +53,9 @@ require 'schleuder/version'
 require 'schleuder/logger_notifications'
 require 'schleuder/logger'
 require 'schleuder/listlogger'
-require 'schleuder/plugin_runners/base'
-require 'schleuder/plugin_runners/list_plugins_runner'
-require 'schleuder/plugin_runners/request_plugins_runner'
-Dir["#{libdir}/schleuder/plugins/*.rb"].each do |file|
+require 'schleuder/keyword_handlers_runner'
+require 'schleuder/keyword_handlers/base'
+Dir["#{libdir}/schleuder/keyword_handlers/*.rb"].each do |file|
   require file
 end
 require 'schleuder/filters_runner'
@@ -64,13 +68,10 @@ require 'schleuder/list_builder'
 require 'schleuder/subscription'
 
 # Setup
-ENV["SCHLEUDER_CONFIG"] ||= '/etc/schleuder/schleuder.yml'
-ENV["SCHLEUDER_LIST_DEFAULTS"] ||= '/etc/schleuder/list-defaults.yml'
-ENV["SCHLEUDER_ENV"] ||= 'production'
-ENV["SCHLEUDER_ROOT"] = rootdir.to_s
-# Ensure that gnupg never-ever tries to ask for a passphrase.
-ENV["GPG_TTY"] = "/nonexistant-#{rand}"
-ENV["DISPLAY"] = nil
+ENV['SCHLEUDER_CONFIG'] ||= '/etc/schleuder/schleuder.yml'
+ENV['SCHLEUDER_LIST_DEFAULTS'] ||= '/etc/schleuder/list-defaults.yml'
+ENV['SCHLEUDER_ENV'] ||= 'production'
+ENV['SCHLEUDER_ROOT'] = rootdir.to_s
 
 GPGME::Ctx.set_gpg_path_from_env
 GPGME::Ctx.check_gpg_version
