@@ -8,12 +8,12 @@ module Schleuder
         return false
       end
 
-      Schleuder.logger.debug "Stripping html-part from multipart/alternative-message"
+      Schleuder.logger.debug 'Stripping html-part from multipart/alternative-message'
       mail.parts.delete_if do |part|
         part[:content_type].content_type == 'text/html'
       end
       mail.content_type = 'multipart/mixed'
-      mail.add_pseudoheader(:note, I18n.t("pseudoheaders.stripped_html_from_multialt"))
+      mail.add_pseudoheader(:note, I18n.t('pseudoheaders.stripped_html_from_multialt'))
     end
   end
 end
