@@ -1,7 +1,7 @@
 class EmailValidator <  ActiveModel::EachValidator
   def validate_each(record, attribute, value)
     unless value =~ Conf::EMAIL_REGEXP
-      record.errors[attribute] << (options[:message] || I18n.t("errors.invalid_email"))
+      record.errors.add(attribute, (options[:message] || I18n.t('errors.invalid_email')))
     end
   end
 end
