@@ -1,6 +1,6 @@
 ENV['SCHLEUDER_ENV'] ||= 'test'
 ENV['SCHLEUDER_CONFIG'] = 'spec/schleuder.yml'
-ENV["SCHLEUDER_LIST_DEFAULTS"] = "etc/list-defaults.yml"
+ENV['SCHLEUDER_LIST_DEFAULTS'] = 'etc/list-defaults.yml'
 if ENV['USE_BUNDLER'] != 'false'
   require 'bundler/setup'
   Bundler.setup
@@ -9,21 +9,34 @@ end
 # Check env if we want to run code coverage analysis
 if ENV['CHECK_CODE_COVERAGE'] == 'true'
   require 'simplecov'
-  require 'simplecov-console'
-  SimpleCov::Formatter::Console.table_options = {max_width: 400}
-  SimpleCov.formatter = SimpleCov::Formatter::Console
+  require 'simplecov-html'
+  SimpleCov.formatter = SimpleCov::Formatter::HTMLFormatter
   SimpleCov.start do
     add_filter %r{^/vendor/}
     add_filter %r{^/spec/}
   end
 end
+
+require 'socket'
+# This must be set before require'ing schleuder, because the ENV variable is
+# used in <spec/schleuder.yml>.
+# Find the first local IP address that is not a loopback address. We use this
+# for our sks-mock, which can't use "localhost" because docker, and can't use a
+# static loopback address because we need it to run on IPv4-only and IPv6-only
+# hosts.
+ENV['LOCAL_IP_ADDR'] = Socket.ip_address_list.find{ |a| !a.ipv4_loopback? && !a.ipv6_loopback? }.ip_address
+
 require 'schleuder'
 require 'schleuder/cli'
 require 'database_cleaner'
 require 'factory_bot'
 require 'net/http'
 require 'fileutils'
-require 'socket'
+require 'securerandom'
+
+if ENV['USE_BYEBUG'] != 'false'
+  require 'byebug'
+end
 
 RSpec.configure do |config|
   config.expect_with :rspec do |expectations|
@@ -50,7 +63,7 @@ RSpec.configure do |config|
   end
 
   config.after(:each) do |example|
-    FileUtils.rm_rf(Dir["spec/gnupg/pubring.gpg~"])
+    FileUtils.rm_rf(Dir['spec/gnupg/pubring.gpg~'])
     # gpgconf --kill might hang indefinitely in IPv6-only environments.
     `pkill -f "#{Conf.lists_dir}" || true`
   end
@@ -71,7 +84,7 @@ RSpec.configure do |config|
   end
 
   def cleanup_gnupg_home
-    ENV["GNUPGHOME"] = nil
+    ENV['GNUPGHOME'] = nil
     FileUtils.rm_rf Schleuder::Conf.lists_dir
   end
 
@@ -80,15 +93,19 @@ RSpec.configure do |config|
   end
 
   def with_sks_mock(listdir)
+    # Make dirmngr disable its own, internal resolver, which apparently has
+    # problems with keyserver-URLs containing local IPs.
+    `printf "standard-resolver\n" > "#{listdir}/dirmngr.conf"`
     # Do we deal with an IPv6-only environment?
     # If so, handle dirmngr specifically so it's able to cope with it.
     # No idea what's the relation in regards to 'no-use-tor', but it helps.
     if ! Socket.ip_address_list.find { |ai| ai.ipv4? && ai.ipv4_loopback? }
-      `printf "disable-ipv4\nno-use-tor" > "#{listdir}/dirmngr.conf"`
+      `printf "disable-ipv4\nno-use-tor\n" >> "#{listdir}/dirmngr.conf"`
     end
 
-    pid = Process.spawn('spec/sks-mock.rb', [:out, :err] => ["/tmp/sks-mock.log", 'w'])
-    uri = URI.parse("http://localhost:9999/status")
+    pid = Process.spawn("spec/sks-mock.rb #{ENV['LOCAL_IP_ADDR']}", [:out, :err] => ['/tmp/sks-mock.log', 'w'])
+    sks_base_url = "http://#{ENV['LOCAL_IP_ADDR']}:9999"
+    uri = URI.parse("#{sks_base_url}/status")
     attempts = 25
     # Use the following env var to increase the time to sleep between
     # each attempt, for example if building the Debian package
@@ -105,7 +122,7 @@ RSpec.configure do |config|
       end
     end
 
-    yield
+    yield sks_base_url
 
     Process.kill 'TERM', pid
     Process.wait pid
@@ -176,18 +193,42 @@ RSpec.configure do |config|
     ciphertext.reject { |line| line.match(/^\[GNUPG:\]/) }.join
   end
 
-  def with_tmpfile(content,&blk)
-    file = Tempfile.new('temporary-file',Conf.lists_dir)
+  def capture_output
+    orig_stdout = $stdout
+    $stdout = StringIO.new
+    orig_stderr = $stderr
+    $stderr = StringIO.new
+    exitcode = nil
+
+    begin
+      yield
+    rescue SystemExit => exc
+      exitcode = exc.status
+    end
+
+    $stdout.rewind
+    output = $stdout.read
+    $stderr.rewind
+    errors = $stderr.read
+    # Cleanup
+    $stderr = orig_stderr
+    $stdout = orig_stdout
+
+    [output, errors, exitcode]
+  end
+
+  def with_tmpfile(content, &blk)
+    file = File.new(File.join(Conf.lists_dir, SecureRandom.hex(32)), 'w+')
     begin
       file.write(content)
       file.close
       yield file.path
     ensure
-      file.unlink
+      File.unlink(file)
     end
   end
 
-  def t(*args)
-    I18n.t(*args)
+  def t(key, **kwargs)
+    I18n.t(key, **kwargs)
   end
 end
